@@ -87,6 +87,58 @@ def list(production_name):
             click.echo(f"* {folder}")
 
 
+@main.command()
+@click.argument("production_name", type=production_name_type, nargs=1)
+@click.argument("job_name", type=str, default="", nargs=1)
+def list_checks(production_name, job_name):
+    """List the checks for a specific production by running lb-ap list-checks <YOUR_PRODUCTION> \n
+    List only the checks required by a specific job by running lb-ap list-checks <YOUR_PRODUCTION> <YOUR_JOB>"""
+    inside_ap_datapkg()
+
+    # Check if production exists
+    check_production(production_name)
+
+    # Get rendered yaml and find all the production names
+    with open(os.path.join(production_name, "info.yaml"), "rt") as fp:
+        raw_yaml = fp.read()
+    try:
+        jobs_data, checks_data = parse_yaml(render_yaml(raw_yaml))
+    except Exception:
+        click.secho("Parsed YAML has errors!", fg="red")
+        click.secho(f'See "lb-ap validate {production_name}" for details', fg="red")
+        raise click.ClickException("Failed to parse YAML")
+
+    if len(checks_data) == 0:
+        click.echo(f"No checks are defined for {production_name}")
+        return
+
+    if job_name:
+        try:
+            job_data = jobs_data[job_name]
+        except KeyError:
+            raise click.ClickException(
+                f"Job {job_name} is not found for production {production_name}!"
+            )
+
+        job_checks = job_data.get("checks")
+        if len(job_checks) == 0 or job_checks is None:
+            click.echo(
+                f"None of the checks defined for {production_name} are required by {job_name}"
+            )
+        else:
+            click.echo(
+                f"The checks defined for {production_name} that are required by {job_name} are: "
+            )
+            for cname in job_checks:
+                ctype = checks_data.get(cname).get("type")
+                click.echo(f"* {cname} (type: {ctype})")
+    else:
+        click.echo(f"The checks defined for {production_name} are: ")
+        for cname, cvalue in checks_data.items():
+            ctype = cvalue.get("type")
+            click.echo(f"* {cname} (type: {ctype})")
+
+
 @main.command()
 @click.argument("production_name", type=production_name_type, nargs=1)
 def render(production_name):
@@ -108,7 +160,7 @@ def render(production_name):
     except Exception:
         click.secho("Rendered YAML has errors!", fg="red")
         click.secho(f'See "lb-ap validate {production_name}" for details', fg="red")
-        raise click.ClickException("Failed to parse and valate YAML")
+        raise click.ClickException("Failed to parse and validate YAML")
     else:
         for warning in warnings:
             click.secho(f"WARNING: {warning}", fg="yellow")
@@ -258,7 +310,7 @@ def test(production_name, job_name, dependent_input):
 @click.argument("production_name", type=production_name_type, nargs=1)
 @click.argument("job_name", type=str, nargs=1)
 @click.argument("test_ntuple_path", type=click.Path(exists=True), nargs=1)
-@click.argument("checks_output_dir", type=click.Path(), nargs=1)
+@click.argument("checks_output_dir", type=click.Path(), default="", nargs=1)
 def check(production_name, job_name, test_ntuple_path, checks_output_dir):
     """Run checks for a production"""
     validate_environment()
@@ -267,10 +319,21 @@ def check(production_name, job_name, test_ntuple_path, checks_output_dir):
     # Obtain the right output file name
     with open(os.path.join(production_name, "info.yaml"), "rt") as fp:
         raw_yaml = fp.read()
-    prod_data, checks_data = parse_yaml(render_yaml(raw_yaml))
-    warnings = validate_yaml(prod_data, checks_data, ".", production_name)
-    for warning in warnings:
-        click.secho(f"WARNING: {warning}", fg="yellow")
+    try:
+        prod_data, checks_data = parse_yaml(render_yaml(raw_yaml))
+        warnings = validate_yaml(prod_data, checks_data, ".", production_name)
+    except Exception:
+        click.secho("Rendered YAML has errors!", fg="red")
+        click.secho(f'See "lb-ap validate {production_name}" for details', fg="red")
+        raise click.ClickException("Failed to parse and validate YAML")
+    else:
+        for warning in warnings:
+            click.secho(f"WARNING: {warning}", fg="yellow")
+        click.secho("YAML parsed and validated successfully", fg="green")
+
+    # If checks_output_dir not specified, set it to a "checks" dir in the same directory as the input file
+    if not checks_output_dir:
+        checks_output_dir = join(os.path.dirname(test_ntuple_path), "checks")
 
     # Run checks
     if checks_exist(checks_data):
