@@ -64,6 +64,9 @@ def prepare_test(production_name, job_name, dependent_input=None):
 
     if "bk_query" in job_data["input"]:
         params["bk_query"] = job_data["input"]["bk_query"]
+    elif "transform_ids" in job_data["input"]:
+        params["transform_ids"] = job_data["input"]["transform_ids"]
+        params["filetype"] = job_data["input"]["filetype"]
     elif "job_name" in job_data["input"]:
         dependent_job = job_data["input"]["job_name"]
         # check we only need to handle one output
@@ -83,7 +86,15 @@ def prepare_test(production_name, job_name, dependent_input=None):
                 f"Local input file not found for {job_name}, please check you have provided the correct path."
             )
 
-        params["bk_query"] = prod_data[dependent_job]["input"]["bk_query"]
+        if "bk_query" in job_data["input"]:
+            params["bk_query"] = prod_data[dependent_job]["input"]["bk_query"]
+        elif "transform_ids" in job_data["input"]:
+            params["transform_ids"] = job_data[dependent_job]["transform_ids"]
+            params["filetype"] = job_data[dependent_job]["filetype"]
+        else:
+            raise NotImplementedError(
+                "Input requires either a bookkeeping location or a previous job name"
+            )
         params["override_output_filetype"] = prod_data[dependent_job]["output"][0]
     else:
         raise NotImplementedError(
