@@ -28,13 +28,13 @@ args_parse_log = ["parse-log"]
 def test_main_help(subcommand):
     runner = CliRunner()
     result = runner.invoke(main, subcommand + ["--help"])
-    assert result.exit_code == 0
+    assert result.exit_code == 0, result.stdout
 
 
 def test_main_version():
     runner = CliRunner()
     result = runner.invoke(main, ["--version"])
-    assert result.exit_code == 0
+    assert result.exit_code == 0, result.stdout
     assert "LbAPLocal" in result.stdout
     assert "LbAPCommon" in result.stdout
     assert "LbEnv" in result.stdout
